# LinOSS Sequence Mixer

::: linax.sequence_mixers.linoss.LinOSSSequenceMixerConfig
    options:
        members:
            - build

---

::: linax.sequence_mixers.linoss.LinOSSSequenceMixer
    options:
        members:
            - __init__
            - __call__
